@@ -1,10 +1,11 @@
 # Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
 # SPDX-License-Identifier: Apache-2.0
+from unittest import mock as mocker
+
 import yaml
 from nose2.tools import such, params
 
 from servicecatalog_puppet import constants
-from unittest import mock as mocker
 
 
 @mocker.patch("servicecatalog_puppet.config.get_home_region")
@@ -66,7 +67,7 @@ def test_get_config_with_a_default_region(mocked_betterboto_client):
     assert {"region_name": fake_home_region} == kwargs
 
 
-with such.A("get_config") as it:  # TODO
+with such.A("get_config") as it:
 
     @it.should("work")
     @params(
@@ -102,39 +103,6 @@ with such.A("get_config") as it:  # TODO
 
     it.createTests(globals())
 
-#
-
-# @pytest.mark.parametrize(
-#     "method_to_call,key,expected_result",
-#     [
-#         ("get_regions", "regions", ["eu-west-1", "eu-west-3",]),
-#         ("get_should_use_sns", "should_collect_cloudformation_events", True),
-#         ("get_should_use_eventbridge", "should_forward_events_to_eventbridge", True),
-#         (
-#             "get_should_forward_failures_to_opscenter",
-#             "should_forward_failures_to_opscenter",
-#             True,
-#         ),
-#         ("get_should_use_product_plans", "should_use_product_plans", True),
-#     ],
-# )
-# def test_get_some_config(method_to_call, key, expected_result):
-#     # setup
-#     from servicecatalog_puppet import config as sut
-#     default_region = "eu-west-10"
-#     mocked_get_config = mocker.patch.object(sut, "get_config")
-#     mocked_get_config.return_value = {key: expected_result}
-#
-#     # exercise
-#     f = getattr(sut, method_to_call)
-#     actual_result = f("", default_region)
-#
-#     # verify
-#     args, kwargs = mocked_get_config.call_args
-#     assert expected_result == actual_result
-#     assert args == ("", default_region,)
-#     assert kwargs == {}
-
 
 @mocker.patch(
     "servicecatalog_puppet.config.betterboto_client.CrossAccountClientContextManager"
