@@ -262,29 +262,9 @@ class CodeBuildRunTask(CodeBuildRunForTask):
         }
 
     def requires(self):
-        regional_dependencies = list()
-        account_dependencies = list()
-        account_and_region_dependencies = list()
-        requirements = dict(
-            regional_launches=regional_dependencies,
-            account_launches=account_dependencies,
-            account_and_region_dependencies=account_and_region_dependencies,
-        )
-
-        for region in self.manifest.get_regions_used_for_section_item(
-            self.puppet_account_id, self.section_name, self.code_build_run_name
-        ):
-            regional_dependencies.append(
-                CodeBuildRunForRegionTask(**self.param_kwargs, region=region,)
-            )
-
-        for account_id in self.manifest.get_account_ids_used_for_section_item(
-            self.puppet_account_id, self.section_name, self.code_build_run_name
-        ):
-            account_dependencies.append(
-                CodeBuildRunForAccountTask(**self.param_kwargs, account_id=account_id,)
-            )
+        requirements = list()
 
+        klass = self.get_klass_for_provisioning()
         for (
             account_id,
             regions,
@@ -292,11 +272,16 @@ class CodeBuildRunTask(CodeBuildRunForTask):
             self.puppet_account_id, self.section_name, self.code_build_run_name
         ).items():
             for region in regions:
-                account_and_region_dependencies.append(
-                    CodeBuildRunForAccountAndRegionTask(
-                        **self.param_kwargs, account_id=account_id, region=region,
+                for task in self.manifest.get_tasks_for_launch_and_account_and_region(
+                    self.puppet_account_id,
+                    self.section_name,
+                    self.code_build_run_name,
+                    account_id,
+                    region,
+                ):
+                    requirements.append(
+                        klass(**task, manifest_file_path=self.manifest_file_path)
                     )
-                )
 
         return requirements
 
@@ -312,18 +297,26 @@ class CodeBuildRunsSectionTask(CodeBuildRunBaseTask, manifest_tasks.SectionTask)
         }
 
     def requires(self):
-        requirements = dict(
-            invocations=[
-                CodeBuildRunTask(
-                    code_build_run_name=code_build_run_name,
-                    manifest_file_path=self.manifest_file_path,
+        requirements = list()
+
+        for name, details in self.manifest.get(constants.CODE_BUILD_RUNS, {}).items():
+            requirements += self.handle_requirements_for(
+                name,
+                details,
+                constants.CODE_BUILD_RUN,
+                constants.CODE_BUILD_RUNS,
+                self.execution_mode == constants.EXECUTION_MODE_SPOKE,
+                CodeBuildRunForRegionTask,
+                CodeBuildRunForAccountTask,
+                CodeBuildRunForAccountAndRegionTask,
+                CodeBuildRunTask,
+                dict(
+                    code_build_run_name=name,
                     puppet_account_id=self.puppet_account_id,
-                )
-                for code_build_run_name, code_build_run in self.manifest.get(
-                    self.section_name, {}
-                ).items()
-            ]
-        )
+                    manifest_file_path=self.manifest_file_path,
+                ),
+            )
+
         return requirements
 
     def run(self):
