@@ -257,30 +257,9 @@ class LambdaInvocationTask(LambdaInvocationForTask):
         }
 
     def requires(self):
-        regional_dependencies = list()
-        account_dependencies = list()
-        account_and_region_dependencies = list()
-        requirements = dict(
-            regional_launches=regional_dependencies,
-            account_launches=account_dependencies,
-            account_and_region_dependencies=account_and_region_dependencies,
-        )
-        for region in self.manifest.get_regions_used_for_section_item(
-            self.puppet_account_id, self.section_name, self.lambda_invocation_name
-        ):
-            regional_dependencies.append(
-                LambdaInvocationForRegionTask(**self.param_kwargs, region=region,)
-            )
-
-        for account_id in self.manifest.get_account_ids_used_for_section_item(
-            self.puppet_account_id, self.section_name, self.lambda_invocation_name
-        ):
-            account_dependencies.append(
-                LambdaInvocationForAccountTask(
-                    **self.param_kwargs, account_id=account_id,
-                )
-            )
+        requirements = list()
 
+        klass = self.get_klass_for_provisioning()
         for (
             account_id,
             regions,
@@ -288,11 +267,16 @@ class LambdaInvocationTask(LambdaInvocationForTask):
             self.puppet_account_id, self.section_name, self.lambda_invocation_name
         ).items():
             for region in regions:
-                account_and_region_dependencies.append(
-                    LambdaInvocationForAccountAndRegionTask(
-                        **self.param_kwargs, account_id=account_id, region=region,
+                for task in self.manifest.get_tasks_for_launch_and_account_and_region(
+                    self.puppet_account_id,
+                    self.section_name,
+                    self.lambda_invocation_name,
+                    account_id,
+                    region,
+                ):
+                    requirements.append(
+                        klass(**task, manifest_file_path=self.manifest_file_path)
                     )
-                )
 
         return requirements
 
@@ -310,18 +294,27 @@ class LambdaInvocationsSectionTask(
         }
 
     def requires(self):
-        requirements = dict(
-            invocations=[
-                LambdaInvocationTask(
-                    lambda_invocation_name=lambda_invocation_name,
-                    manifest_file_path=self.manifest_file_path,
+        requirements = list()
+
+        for name, details in self.manifest.get(
+            constants.LAMBDA_INVOCATIONS, {}
+        ).items():
+            requirements += self.handle_requirements_for(
+                name,
+                details,
+                constants.LAMBDA_INVOCATION,
+                constants.LAMBDA_INVOCATIONS,
+                self.execution_mode == constants.EXECUTION_MODE_SPOKE,
+                LambdaInvocationForRegionTask,
+                LambdaInvocationForAccountTask,
+                LambdaInvocationForAccountAndRegionTask,
+                LambdaInvocationTask,
+                dict(
+                    lambda_invocation_name=name,
                     puppet_account_id=self.puppet_account_id,
-                )
-                for lambda_invocation_name, lambda_invocation in self.manifest.get(
-                    self.section_name, {}
-                ).items()
-            ]
-        )
+                    manifest_file_path=self.manifest_file_path,
+                ),
+            )
         return requirements
 
     def run(self):
